@@ -1,6 +1,6 @@
 package Form::Sensible::Field::Select;
 
-use Moose; 
+use Moose;
 use namespace::autoclean;
 use Form::Sensible::DelegateConnection;
 
@@ -26,7 +26,7 @@ has 'options_delegate' => (
     default     => sub {
                             my $self = shift;
                             my $obj = $self;
-                            
+
                             return FSConnector( sub { return $obj->options } );
                    },
     lazy        => 1,
@@ -44,7 +44,7 @@ has 'values_ok_delegate' => (
                             return FSConnector( sub {
                                 my $caller = shift;
                                 my $values = shift;
-                                
+
                                 my @errors;
                                 foreach my $value (@{$values}) {
                                     my $valid = 0;
@@ -58,7 +58,7 @@ has 'values_ok_delegate' => (
                                         if (exists($caller->validation->{'invalid_message'})) {
                                             push @errors, $caller->validation->{'invalid_message'};
                                         } else {
-                                            push @errors, "_FIELDNAME_ was set to an invalid value";            
+                                            push @errors, "_FIELDNAME_ was set to an invalid value";
                                         }
                                     }
                                 }
@@ -70,47 +70,45 @@ has 'values_ok_delegate' => (
     # additional options
 );
 
-## Select has special handling, it's value is ALWAYS returned as an array, so we have to 
-## provide our own default 'value_delegate' to negate the default value_delegate behavior of 
+## Select has special handling, it's value is ALWAYS returned as an array, so we have to
+## provide our own default 'value_delegate' to negate the default value_delegate behavior of
 ## eating arrayrefs when accepts_multiple is false.
 
 
 sub get_additional_configuration {
     my ($self) = @_;
-    
-    return { 
-                'options' => $self->options,
-           };    
+
+    return { map { $_ => $self->$_ } qw/accepts_multiple options/  };
 }
 
 sub set_selection {
     my ($self) = shift;
-    
+
     $self->value( [ ] );
     return $self->add_selection(@_);
 }
 
 sub add_selection {
     my ($self) = shift;
-    
+
     if (!$self->accepts_multiple) {
-        $self->value(@_);
-    } else {
-        if (!defined($self->value()) || ref($self->value()) ne 'ARRAY') {
-            $self->value( [ ] );
-        }
-        
-        my %selection = map { $_ => 1 } @{$self->value()};
-        my $providedoptions = [ @_ ];
-        if ($#_ == 0 && ref($_[0]) eq 'ARRAY') {
-            $providedoptions = $_[0];
-        }
-        
-        foreach my $item (@{$providedoptions}) {
-            if (!exists($selection{$item})) {
-                push @{$self->value()}, $item;
-                $selection{$item} = 1;
-            }
+        return $self->value(@_);
+    }
+
+    if (!defined($self->value()) || ref($self->value()) ne 'ARRAY') {
+        $self->value( [ ] );
+    }
+
+    my %selection = map { $_ => 1 } @{$self->value()};
+    my $providedoptions = [ @_ ];
+    if ($#_ == 0 && ref($_[0]) eq 'ARRAY') {
+        $providedoptions = $_[0];
+    }
+
+    foreach my $item (@{$providedoptions}) {
+        if (!exists($selection{$item})) {
+            push @{$self->value()}, $item;
+            $selection{$item} = 1;
         }
     }
     return $self->value();
@@ -118,21 +116,20 @@ sub add_selection {
 
 sub add_option {
     my ($self, $value, $display_name) = @_;
-    
-    push @{$self->options}, { name => $display_name,
-                               value => $value };
+
+    push @{$self->options}, { name => $display_name, value => $value };
 }
 
 sub get_options {
     my ($self) = shift;
-    
+
     $self->options_delegate->($self, @_);
 }
 
 around 'validate' => sub {
     my $orig = shift;
     my $self = shift;
-    
+
     my $values;
     if (ref($self->value) eq 'ARRAY') {
         $values = $self->value;
@@ -143,32 +140,31 @@ around 'validate' => sub {
     use Data::Dumper;
     #warn Dumper($values);
     #warn Dumper($self->options);
-    
+
     push @errors, $self->$orig(@_);
-    
+
     push @errors, $self->values_ok_delegate->($self, $values);
-    
+
     return @errors;
 };
 
 around 'value' => sub {
     my $orig = shift;
     my $self = shift;
-    
-    if ($#_ == -1) { 
+
+    if ($#_ == -1) {
         return $self->$orig();
-    } else {
-        my $values;
-        if (ref($_[0]) ne 'ARRAY') 
-        {
-            $values = [ ];
-            push @{$values}, @_;
-        } else {
-            $values = $_[0];            
-        }
-        return $self->$orig($values);
     }
-    
+
+    my $values;
+    if (ref($_[0]) ne 'ARRAY')
+    {
+        $values = [ ];
+        push @{$values}, @_;
+    } else {
+        $values = $_[0];
+    }
+    return $self->$orig($values);
 };
 
 __PACKAGE__->meta->make_immutable;
@@ -184,7 +180,7 @@ Form::Sensible::Field::Select - A multiple-choice option field
 
     use Form::Sensible::Field::Select;
     
-    my $select_field = Form::Sensible::Field::Select->new( 
+    my $select_field = Form::Sensible::Field::Select->new(
                                                          name => 'bread_type'
                                                          accepts_multiple => 1
                                                     );
@@ -199,49 +195,60 @@ Form::Sensible::Field::Select - A multiple-choice option field
 
 =head1 DESCRIPTION
 
-This Field type allows a user to select one or more options from a
-provided set of options.  This could be rendered as a select box,
-a radio group or even a series of checkboxes, depending on the renderer
-and the render_hints provided.
+This L<Field|Form::Sensible::Field> type allows a user to select one or more
+options from a provided set of options.  This could be rendered as a select
+box, a radio group or even a series of checkboxes, depending on the renderer
+and the render hints provided.
 
 =head1 ATTRIBUTES
 
 =over 8
 
-
 =item C<accepts_multiple>
 
-Does this field allow multiple options to be selected.  Defaults to false.
-B<Note> that the value returned by a select field where 'accepts_multiple' is true 
-will always be an arrayref, even if only a single option was selected.
+Flag for if this field allows multiple options to be selected.  Defaults to
+false.  B<Note> that the value returned by a select field where
+'accepts_multiple' is true will always be an arrayref, even if only a single
+option was selected.
 
+=item C<options>
 
-=back 
+The options for the Select field as an array ref. See
+L<get_options()|/"METHODS">.
+
+=back
 
 =head1 METHODS
 
 =over 8
 
-=item C<get_options()> 
+=item C<get_options()>
 
-Returns an array ref containing the allowed options. Each option is represented as a
-hash containing a C<name> element and a C<value> element for the given option.
+Returns an array ref containing the allowed options. Each option is
+represented as a hash containing a C<name> element and a C<value> element for
+the given option.
 
-=item C<add_selection($selected_option,...)> 
+=item C<add_selection($selected_option,...)>
 
-Adds the provided option values as selected.  If C<accepts_multiple> is 
-true, the provided options will be set B<IN ADDITION> to any existing selections;
+Adds the provided option values as selected.  If C<accepts_multiple> is true,
+the provided options will be set B<IN ADDITION> to any existing selections.
 
-=item C<set_selection($selected_option,...)> 
+=item C<set_selection($selected_option,...)>
 
-Set's the provided option values as selected.  If C<accepts_multiple> is 
-false, only the first item will be set as selected.  
+Sets the provided option values as selected.  If C<accepts_multiple> is false,
+only the first item will be set as selected.
 
 
 =item C<add_option($option_value, $option_display_name)>
 
-If no C<options_delegate> was provided - Adds the provided value and display name to the set of options that can
-be selected for this field.  If an options_delegate I<IS> provided, has no effect whatsoever.
+If an C<options_delegate> I<IS> provided, has no effect whatsoever. Otherwise
+it adds the provided value and display name to the set of options that can be
+selected for this field.
+
+=item C<get_additional_configuration>
+
+Returns the additional configuration attributes for this Field class as a
+hashref.
 
 =back
 
@@ -249,15 +256,15 @@ be selected for this field.  If an options_delegate I<IS> provided, has no effec
 
 =over 8
 
-=item options_delegate->($self)
+=item C<<options_delegate->($self)>>
 
 The C<options_delegate> is called to obtain the valid options for this field.
-Is expected to return an array ref of options. Each option should be a hash
+It is expected to return an array ref of options. Each option should be a hash
 entry with a C<name> key and a C<value> key. If no C<options_delegate> is
 provided, defaults to delegating to itself, using internal storage of options
 (using the C<add_option> mechanism outlined above)
 
-=item values_ok_delegate->($self, $values_arrayref)
+=item C<<values_ok_delegate->($self, $values_arrayref)>>
 
 The C<values_ok_delegate> is called to validate the values selected for the
 field. It is passed an arrayref containing the selected values and should
@@ -269,6 +276,8 @@ each value provided in turn. If retrieving options is an expensive operation
 values provided rather than pulling back all options and then comparing them.
 This delegate action provides for that possibility.
 
+=back
+
 =head1 AUTHOR
 
 Jay Kuri - E<lt>jayk@cpan.orgE<gt>
@@ -287,4 +296,4 @@ Copyright 2009 by Jay Kuri E<lt>jayk@cpan.orgE<gt>
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
